%define cvs	20080216
%if %cvs
%define release	%mkrel 0.%cvs.1
%else
%define release	%mkrel 2
%endif
%define	with_python	--with-python=%_bindir/python

%define major		7
%define libname		%mklibname %name %major
%define develname	%mklibname %name -d

Summary:	An open source cryptography library
Name:		beecrypt
Version:	4.2.0
Release:	%{release}
Group:		System/Libraries
License:	LGPLv2+
URL:		http://beecrypt.sourceforge.net/
%if %cvs
Source0:	%{name}-%{cvs}.tar.lzma
%else
Source0:	http://prdownloads.sourceforge.net/beecrypt/%{name}-%{version}.tar.bz2
%endif
Patch0:		beecrypt-4.1.2-biarch.patch
# AdamW: ugly patch simply defines upstream's odd libaltdir variable to be 
# equal to libdir in one places. Also replaces a similarly weird pythondir
# variable with hardcoded $(libdir)/python2.5 , so will stop working when
# python goes to 2.6. I expect upstream to have a better fix for this issue
# by then, so it won't matter. The problem is that beecrypt tries to set this
# libaltdir variable to /usr/lib or /usr/lib64 depending on the arch in use
# which it tests by grepping the default CFLAGS for --march=x86_64 . Ours
# don't include this, so the test breaks. Upstream should simply be using
# standard libdir variable. (This is mostly fixed now (2008/02), only two
# instances left).
Patch1:		beecrypt-4.2.0-lib64.patch
# Obvious typo "retach" for "detach" breaks build - will submit
# upstream - AdamW 2008/02
Patch2:		beecrypt-4.2.0-typo.patch
BuildRequires:	doxygen
BuildRequires:	tetex-dvips
BuildRequires:	tetex-latex
BuildRequires:	graphviz
BuildRequires:	m4
%if %{?with_python:1}0
BuildRequires:	python-devel >= %{pyver}
%endif
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-buildroot

%description
Beecrypt is a general-purpose cryptography library.

%package -n	%{libname}
Summary:	An open source cryptography library
Group:		System/Libraries

%description -n %{libname}
Beecrypt is a general-purpose cryptography library.

%package -n	%{develname}
Summary:	Files needed for developing applications with beecrypt
Group:		Development/C
Requires:	%{libname} = %{version}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Obsoletes:	%{mklibname beecrypt 7 -d}

%description -n	%{develname}
Beecrypt is a general-purpose cryptography library.  This package contains
files needed for developing applications with beecrypt.

%if %{?with_python:1}0
%package	python
Summary:	Files needed for python applications using beecrypt
Group:		Development/C
Requires:	python >= %{pyver}
Requires:	%{libname} = %{version}

%description	python
Beecrypt is a general-purpose cryptography library.  This package contains
files needed for using python with beecrypt.
%endif

%prep
%if %cvs
%setup -q -n %{name}
%else
%setup -q
%endif
%patch0 -p1 -b .biarch
%patch1 -p0 -b .lib64
%patch2 -p1 -b .typo

%build
%if %cvs
./autogen.sh
%endif

%configure	--enable-shared \
		--enable-static \
		%{?with_python} \
		CPPFLAGS="-I%{_includedir}/python%{pyver}"

%make
cd include/beecrypt
doxygen
cd c++
doxygen
cd ../../..

# XXX delete next line to build with legacy, non-check aware, rpmbuild.
%check
make check || :
cat /proc/cpuinfo
make bench || :

%install
rm -fr %{buildroot}
%{makeinstall_std}

# XXX nuke unpackaged files, artifacts from using libtool to produce module
rm -f %{buildroot}%{_libdir}/python%{pyver}/site-packages/_bc.*a

%clean
rm -fr %{buildroot}

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr(-,root,root)
%doc README BENCHMARKS
%{_libdir}/*.so.%{major}*

%files -n %{develname}
%defattr(-,root,root)
%doc BUGS docs/html docs/latex
%{_includedir}/%{name}
%{_libdir}/*.a
%{_libdir}/*.la
%{_libdir}/*.so

%if %{?with_python:1}0
%files python
%defattr(-,root,root)
%{_libdir}/python%{pyver}/site-packages/_bc.so
%endif



%changelog
* Sat Feb 16 2008 Adam Williamson <awilliamson@mandriva.com> 4.2.0-0.20080216.1mdv2008.1
+ Revision: 169321
- specify location of python in --with-python parameter, configure test seems to be broken somehow
- use system %%pyver macro
- add typo.patch that fixes build when C++ stuff is built (not in our default build but might affect people doing rebuilds)
- rediff lib64.patch
- minor cleanups
- new devel policy
- new snapshot
- build all docs

  + Thierry Vignaud <tvignaud@mandriva.com>
    - rebuild
    - kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Pixel <pixel@mandriva.com>
    - add explicit conflict on libbeecrypt6-devel

* Wed Apr 25 2007 Adam Williamson <awilliamson@mandriva.com> 4.2.0-0.20070425.1mdv2008.0
+ Revision: 18192
- reorder patches, add new patch1 to fix x86-64 build
- enable tests
- major has gone up to 7 upstream
- use CVS to see if it builds right on x86-64
- sync spec and patches with Fedora
- buildrequires graphviz for doc generation
- 4.1.2


* Fri May 12 2006 Stefan van der Eijk <stefan@eijk.nu> 3.1.0-7mdk
- rebuild for sparc

* Sat Dec 31 2005 Mandriva Linux Team <http://www.mandrivaexpert.com/> 3.1.0-6mdk
- Rebuild

* Mon Jan 31 2005 Frederic Lepied <flepied@mandrakesoft.com> 3.1.0-5mdk
-

* Sat Dec 25 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 3.1.0-4mdk
- fix build with current python
- fix group
- cosmetics

* Sun Jun 20 2004 Stefan van der Eijk <stefan@mandrake.org> 3.1.0-3mdk
- patch2: alpha doesn't use lib64

* Wed Feb 18 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 3.1.0-2mdk
- automake1.7

* Fri Jan 16 2004 Frederic Lepied <flepied@mandrakesoft.com> 3.1.0-1mdk
- initial Mandrake Linux packaging

* Mon Dec 22 2003 Jeff Johnson <jbj@jbj.org> 3.1.0-1
- upgrade to 3.1.0.
- recompile against python-2.3.3.

* Mon Jun 30 2003 Jeff Johnson <jbj@redhat.com> 3.0.1-0.20030630
- upstream fixes for DSA and ppc64.

* Mon Jun 23 2003 Jeff Johnson <jbj@redhat.com> 3.0.0-2
- upgrade to 3.0.0 final.
- fix for DSA (actually, modulo inverse) sometimes failing.

* Fri Jun 20 2003 Jeff Johnson <jbj@redhat.com> 3.0.0-1.20030619
- avoid asm borkage on ppc64.

* Thu Jun 19 2003 Jeff Johnson <jbj@redhat.com> 3.0.0-1.20030618
- rebuild for release bump.

* Tue Jun 17 2003 Jeff Johnson <jbj@redhat.com> 3.0.0-1.20030616
- try to out smart libtool a different way.
- use $bc_target_cpu, not $bc_target_arch, to detect /usr/lib64.

* Mon Jun 16 2003 Jeff Johnson <jbj@redhat.com> 3.0.0-1.20030615
- use -mcpu=powerpc64 on ppc64.

* Fri Jun 13 2003 Jeff Johnson <jbj@redhat.com> 3.0.0-1.20030613
- upgrade to latest snapshot.

* Fri Jun 06 2003 Jeff Johnson <jbj@redhat.com> 3.0.0-1.20030605
- rebuild into another tree.

* Wed Jun 04 2003 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Tue Jun 03 2003 Jeff Johnson <jbj@redhat.com> 3.0.0-0.20030603
- update to 3.0.0 snapshot, fix mpmod (and DSA) on 64b platforms.

* Mon Jun 02 2003 Jeff Johnson <jbj@redhat.com> 3.0.0-0.20030602
- update to 3.0.0 snapshot, merge patches, fix gcd rshift and ppc problems.

* Thu May 29 2003 Jeff Johnson <jbj@redhat.com> 3.0.0-0.20030529
- update to 3.0.0 snapshot, fix ia64/x86_64 build problems.

* Wed May 28 2003 Jeff Johnson <jbj@redhat.com> 3.0.0-0.20030528
- upgrade to 3.0.0 snapshot, adding rpm specific base64.[ch] changes.
- add PYTHONPATH=.. so that "make check" can test the just built _bc.so module.
- grab cpuinfo and run "make bench".
- continue ignoring "make check" failures, LD_LIBRARY_PATH needed for _bc.so.
- skip asm build failure on ia64 for now.
- ignore "make bench" exit codes too, x86_64 has AES segfault.

* Wed May 21 2003 Jeff Johnson <jbj@redhat.com> 3.0.0-0.20030521
- upgrade to 3.0.0 snapshot, including python subpackage.
- ignore "make check" failure for now.

* Fri May 16 2003 Jeff Johnson <jbj@redhat.com> 3.0.0-0.20030516
- upgrade to 3.0.0 snapshot, including ia64 and x86_64 fixes.
- add %%check.
- ignore "make check" failure on ia64 for now.

* Mon May 12 2003 Jeff Johnson <jbj@redhat.com> 3.0.0-0.20030512
- upgrade to 3.0.0 snapshot.
- add doxygen doco.
- use /dev/urandom as default entropy source.
- avoid known broken compilation for now.

